@@ -6,6 +6,7 @@ import contextlib
 import io
 import os
 import unittest
+import unittest.mock
 
 import things
 
@@ -164,6 +165,10 @@ class ThingsCase(unittest.TestCase):  # noqa: V103 pylint: disable=R0904
     def test_logbook(self):
         tasks = things.logbook()
         self.assertEqual(21, len(tasks))
+        tasks = things.logbook(stop_date="2099-03-29")
+        self.assertEqual(0, len(tasks))
+        tasks = things.logbook(stop_date="2021-03-28")
+        self.assertEqual(21, len(tasks))
 
     def test_canceled(self):
         tasks = things.canceled()
@@ -266,6 +271,9 @@ class ThingsCase(unittest.TestCase):  # noqa: V103 pylint: disable=R0904
         count = things.tasks(status="completed", last="100y", count_only=True)
         self.assertEqual(count, 10)
 
+        count = things.last("1y", tag="Important", status="completed", count_only=True)
+        self.assertEqual(count, 0)
+
         # get task by uuid
         count = things.tasks(uuid="5pUx6PESj3ctFYbgth1PXY", count_only=True)
         self.assertEqual(count, 1)
@@ -299,6 +307,11 @@ class ThingsCase(unittest.TestCase):  # noqa: V103 pylint: disable=R0904
             database.get_tags()
         self.assertTrue("/* Filepath" in output.getvalue())
 
+    @unittest.mock.patch("os.system")
+    def test_api_show(self, os_system):  # pylint: disable=R0201
+        things.show("invalid_uuid")
+        os_system.assert_called_once_with("open 'things:///show?id=invalid_uuid'")
+
 
 if __name__ == "__main__":
     unittest.main()
