@@ -5,6 +5,7 @@ import plistlib
 import re
 import sqlite3
 from textwrap import dedent
+import datetime
 
 
 # --------------------------------------------------
@@ -83,6 +84,7 @@ DATE_CREATED = "creationDate"
 DATE_DEADLINE = "dueDate"
 DATE_MODIFIED = "userModificationDate"
 DATE_START = "startDate"
+DATE_STOP = "stopDate"
 
 # --------------------------------------------------
 # Various filters
@@ -161,7 +163,7 @@ class Database:
         # Automated migration to new database location in Things 3.12.6/3.13.1
         # --------------------------------
         try:
-            with open(self.filepath) as file:
+            with open(self.filepath, encoding="utf-8") as file:
                 if "Your database file has been moved there" in file.readline():
                     self.filepath = DEFAULT_FILEPATH
         except (UnicodeDecodeError, FileNotFoundError, PermissionError):
@@ -181,6 +183,7 @@ class Database:
         heading=None,
         tag=None,
         start_date=None,
+        stop_date=None,
         deadline=None,
         deadline_suppressed=None,
         trashed=False,
@@ -246,6 +249,7 @@ class Database:
             {make_filter("TASK.dueDateSuppressionDate", deadline_suppressed)}
             {make_filter("TAG.title", tag)}
             {make_date_filter(f"TASK.{DATE_START}", start_date)}
+            {make_date_filter(f"TASK.{DATE_STOP}", stop_date)}
             {make_date_filter(f"TASK.{DATE_DEADLINE}", deadline)}
             {make_date_range_filter(f"TASK.{DATE_CREATED}", last)}
             {make_search_filter(search_query)}
@@ -325,7 +329,7 @@ class Database:
                     WHEN CHECKLIST_ITEM.{IS_CANCELED} THEN 'canceled'
                     WHEN CHECKLIST_ITEM.{IS_COMPLETED} THEN 'completed'
                 END AS status,
-                date(CHECKLIST_ITEM.stopDate, "unixepoch") AS stop_date,
+                date(CHECKLIST_ITEM.stopDate, "unixepoch", "localtime") AS stop_date,
                 'checklist-item' as type,
                 CHECKLIST_ITEM.uuid,
                 datetime(
@@ -472,6 +476,8 @@ def make_tasks_sql_query(where_predicate=None, order_predicate=None):
     where_predicate = where_predicate or "TRUE"
     order_predicate = order_predicate or 'TASK."index"'
 
+    # Note: see remark at `make_date_filter()` as for why the first
+    # two `date()` statements have no "localtime" modifier.
     return f"""
             SELECT DISTINCT
                 TASK.uuid,
@@ -521,7 +527,7 @@ def make_tasks_sql_query(where_predicate=None, order_predicate=None):
                 END AS checklist,
                 date(TASK.startDate, "unixepoch") AS start_date,
                 date(TASK.{DATE_DEADLINE}, "unixepoch") AS deadline,
-                date(TASK.stopDate, "unixepoch") AS "stop_date",
+                date(TASK.stopDate, "unixepoch", "localtime") AS "stop_date",
                 datetime(TASK.{DATE_CREATED}, "unixepoch", "localtime") AS created,
                 datetime(TASK.{DATE_MODIFIED}, "unixepoch", "localtime") AS modified,
                 TASK.'index',
@@ -635,9 +641,10 @@ def make_date_filter(date_column: str, value) -> str:
     date_column : str
         Name of the column that has date information on a task.
 
-    value : bool, 'future', 'past', or None
+    value : bool, 'future', 'past', ISO 8601 date str, or None
         `True` or `False` indicates whether a date is set or not.
         `'future'` or `'past'` indicates a date in the future or past.
+        ISO 8601 date str is in the format "YYYY-MM-DD".
         `None` indicates any value.
 
     Returns
@@ -648,14 +655,17 @@ def make_date_filter(date_column: str, value) -> str:
 
     Examples
     --------
-    >>> make_date_filter('start_date', True)
-    'AND start_date IS NOT NULL'
+    >>> make_date_filter('startDate', True)
+    'AND startDate IS NOT NULL'
 
-    >>> make_date_filter('start_date', False)
-    'AND start_date IS NULL'
+    >>> make_date_filter('startDate', False)
+    'AND startDate IS NULL'
 
-    >>> make_date_filter('start_date', 'future')
-    "AND datetime(start_date, 'unixepoch') > datetime('now')"
+    >>> make_date_filter('startDate', 'future')
+    "AND date(startDate, 'unixepoch') > date('now', 'localtime')"
+
+    >>> make_date_filter('stopDate', '2021-03-28')
+    "AND date(stopDate, 'unixepoch') >= date('2021-03-28')"
 
     >>> make_date_filter('created', None)
     ''
@@ -667,9 +677,25 @@ def make_date_filter(date_column: str, value) -> str:
     if isinstance(value, bool):
         return make_filter(date_column, value)
 
-    validate("value", value, ["future", "past"])
-    operator = ">" if value == "future" else "<="
-    return f"AND datetime({date_column}, 'unixepoch') {operator} datetime('now')"
+    try:
+        # Check for ISO 8601 date str
+        datetime.date.fromisoformat(value)
+        threshold = f"date('{value}')"
+        comparator = '>='
+    except ValueError:
+        # "future" or "past"
+        validate("value", value, ["future", "past"])
+        threshold = "date('now', 'localtime')"
+        comparator = ">" if value == "future" else "<="
+
+    # Note: not using "localtime" modifier on `date()` since Things.app
+    # seems to store `startDate` and `dueDate` as a 00:00 UTC datetime.
+    # Morever, note that `stopDate` -- contrary to its name -- seems to
+    # be stored as the full UTC datetime of when the task was "stopped".
+    # See also: https://github.com/thingsapi/things.py/issues/93
+    date = f"date({date_column}, 'unixepoch')"
+
+    return f"AND {date} {comparator} {threshold}"
 
 
 def make_date_range_filter(date_column, offset) -> str:
@@ -754,12 +780,8 @@ def make_search_filter(query: str) -> str:
 
     Example:
     --------
-    >>> make_search_filter('dinner')
-    'AND (
-        TASK.title LIKE "%dinner%"
-        OR TASK.notes LIKE "%dinner%"
-        OR AREA.title LIKE "%dinner%"
-    )'
+    >>> make_search_filter('dinner') #doctest: +REPORT_NDIFF
+    "AND (TASK.title LIKE '%dinner%' OR TASK.notes LIKE '%dinner%' OR AREA.title LIKE '%dinner%')"
     """
     if not query:
         return ""
@@ -791,16 +813,19 @@ def validate(parameter, argument, valid_arguments):
     Examples
     --------
     >>> validate(
-        parameter='status',
-        argument='completed',
-        valid_arguments=['incomplete', 'completed']
-    )
+    ...     parameter='status',
+    ...     argument='completed',
+    ...     valid_arguments=['incomplete', 'completed']
+    ... )
+    ...
 
     >>> validate(
-        parameter='status',
-        argument='XYZXZY',
-        valid_arguments=['incomplete', 'completed']
-    )
+    ...     parameter='status',
+    ...     argument='XYZXZY',
+    ...     valid_arguments=['incomplete', 'completed']
+    ... )
+    Traceback (most recent call last):
+    ...
     ValueError: Unrecognized status type: 'XYZXZY'
     Valid status types are ['incomplete', 'completed']
     """
@@ -822,8 +847,10 @@ def validate_offset(parameter, argument):
     >>> validate_offset(parameter='last', argument='3d')
 
     >>> validate_offset(parameter='last', argument='XYZ')
-    ValueError: Invalid last argument: 'XYZ'
+    Traceback (most recent call last):
     ...
+    ValueError: Invalid last argument: 'XYZ'
+    Please specify a string of the format 'X[d/w/y]' where X is ...
     """
     if argument is None:
         return
